@@ -1,5 +1,8 @@
+from copy import copy
+
 import django.conf
 
+import django.test.utils
 from django.utils.six import iteritems
 
 
@@ -14,6 +17,7 @@ class Settings(object):
         'OTP_TWILIO_AUTH': None,
         'OTP_TWILIO_FROM': None,
         'OTP_TWILIO_NO_DELIVERY': False,
+        'OTP_TWILIO_TOKEN_TEMPLATE': '{token}',
     }
 
     def __init__(self):
@@ -26,4 +30,17 @@ class Settings(object):
             setattr(self, name, value)
 
 
+class override_settings(django.test.utils.override_settings):
+    def enable(self):
+        self._twilio_settings = copy(settings)
+        for name, value in self.options.items():
+            setattr(settings, name, value)
+
+    def disable(self):
+        for name in self.options:
+            value = getattr(self._twilio_settings, name)
+            setattr(settings, name, value)
+        self._twilio_settigs = None
+
+
 settings = Settings()
