@@ -1,8 +1,12 @@
+import re
+
 from django.db import IntegrityError
 
 from django_otp.oath import totp
 from django_otp.tests import TestCase
 
+from .conf import override_settings
+
 
 class TestTwilioSMS(TestCase):
     def setUp(self):
@@ -51,3 +55,12 @@ class TestTwilioSMS(TestCase):
         ok = self.bob.twiliosmsdevice_set.get().verify_token(token)
 
         self.assertTrue(not ok)
+
+    @override_settings(OTP_TWILIO_TOKEN_TEMPLATE='Token is {token}')
+    def test_format(self):
+        device = self.alice.twiliosmsdevice_set.get()
+        token = device.generate_challenge()
+        match = re.match(r'Token is (\d{6})', token)
+
+        self.assertTrue(match is not None)
+        self.assertTrue(device.verify_token(match.group(1)))
